@@ -4,7 +4,7 @@
 
 /* nettle, low-level cryptographics library
  *
- * Copyright (C) 2002 Niels Mller
+ * Copyright (C) 2002 Niels Möller
  *  
  * The nettle library is free software; you can redistribute it and/or modify
  * it under the terms of the GNU Lesser General Public License as published by
@@ -18,8 +18,8 @@
  * 
  * You should have received a copy of the GNU Lesser General Public License
  * along with the nettle library; see the file COPYING.LIB.  If not, write to
- * the Free Software Foundation, Inc., 59 Temple Place - Suite 330, Boston,
- * MA 02111-1307, USA.
+ * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston,
+ * MA 02111-1301, USA.
  */
 
 #if HAVE_CONFIG_H
@@ -31,6 +31,9 @@
 #include <stdlib.h>
 #include <stdio.h>
 #include <string.h>
+#ifdef WIN32
+#include <fcntl.h>
+#endif
 
 /* string.h must be included before gmp.h */
 #include "aes.h"
@@ -45,8 +48,6 @@
 #include "io.h"
 #include "rsa-session.h"
 
-#include "getopt.h"
-
 void
 rsa_session_set_decrypt_key(struct rsa_session *ctx,
 			    const struct rsa_session_info *key)
@@ -122,9 +123,12 @@ process_file(struct rsa_session *ctx,
   unsigned padding;
 
   size = fread(buffer, 1, BUF_FINAL, in);
-  if (size < BUF_FINAL || ferror(in))
+  if (size < BUF_FINAL)
     {
-      werror("Reading input failed: %s\n", strerror(errno));
+      if (ferror(in))
+	werror("Reading input failed: %s\n", strerror(errno));
+      else
+	werror("Unexpected EOF on input.\n");
       return 0;
     }
 
@@ -132,7 +136,7 @@ process_file(struct rsa_session *ctx,
     {
       size = fread(buffer + BUF_FINAL, 1, BUF_SIZE, in);
 
-      if (ferror(in))
+      if (size < BUF_SIZE && ferror(in))
 	{
 	  werror("Reading input failed: %s\n", strerror(errno));
 	  return 0;
@@ -213,6 +217,11 @@ main(int argc, char **argv)
       return EXIT_FAILURE;
     }
 
+#ifdef WIN32
+  _setmode(0, O_BINARY);
+  _setmode(1, O_BINARY);
+#endif
+
   if (!read_version(stdin))
     {
       werror("Bad version number in input file.\n");
