@@ -145,16 +145,14 @@ do {						\
 
 #define ROTL64(n,x) (((x)<<(n)) | ((x)>>(64-(n))))
 
-/* Requires that size >= 2 */
+/* Requires that size > 0 */
 #define INCREMENT(size, ctr)			\
   do {						\
     unsigned increment_i = (size) - 1;		\
     if (++(ctr)[increment_i] == 0)		\
-      {						\
-	while (++(ctr)[--increment_i] == 0	\
-	       && increment_i > 0)		\
-	  ;					\
-      }						\
+      while (increment_i > 0			\
+	     && ++(ctr)[--increment_i] == 0 )	\
+	;					\
   } while (0)
 
 
